# reliabots (work in progress)
 
Make your machine learning model more reliable with conformal prediction!

Install with
```
pip install reliabots
```
The Conformal Prediction framework is described in a book by [Vovk et al. (2005)](http://alrw.net). 

[A Tutorial on Conformal Prediction](https://jmlr.org/papers/volume9/shafer08a/shafer08a.pdf) provides a gentle introduction.
